==> haskell-authenticate-1.3.3.2-98-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate
version: 1.3.3.2
id: authenticate-1.3.3.2-8Ma4VRfYoiz8sq305TeplL
key: authenticate-1.3.3.2-8Ma4VRfYoiz8sq305TeplL
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.
category: Web
author: Michael Snoyman, Hiromi Ishii, Arash Rouhani
exposed: True
exposed-modules:
    Web.Authenticate.Rpxnow Web.Authenticate.OpenId
    Web.Authenticate.BrowserId Web.Authenticate.OpenId.Providers
hidden-modules: Web.Authenticate.Internal OpenId2.Discovery
                OpenId2.Normalization OpenId2.Types OpenId2.XRDS
abi: ea3f4816075b924319ca262faec090a6
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/authenticate-1.3.3.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/authenticate-1.3.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/authenticate-1.3.3.2
hs-libraries: HSauthenticate-1.3.3.2-8Ma4VRfYoiz8sq305TeplL
depends:
    aeson-1.1.2.0-H9d5B7Pgw9tIbOpl8Ot3sY
    attoparsec-0.13.1.0-ETec0FJZJHgARrgZXhaej9 base-4.9.1.0
    blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO bytestring-0.10.8.1
    case-insensitive-1.2.0.10-3Sa52nt2lVR6gZGQE5fZZw
    conduit-1.2.11-LF3u2IjoGXz5B8eRQRwaoW containers-0.5.7.1
    http-conduit-2.2.3.1-EmVWdcVb4pg4No1uLRZwYO
    http-types-0.9.1-IqlxYYwrFhNBj6J7ATsByJ
    monad-control-1.0.2.0-10S0ywqdsCPHnUTlxJLEct
    network-uri-2.6.1.0-GzRvaV3udR3JtWfa3CLYOw
    resourcet-1.1.9-8dcH1R5asu46j8AjnoNKK5
    tagstream-conduit-0.5.5.3-opiAHRQEQ9Dt4aAYl6FfG
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    xml-conduit-1.5.1-8WyflpR3V7N9KUfVCoBUmr
haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
haddock-html: /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-1.3.3.2-99-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate
version: 1.3.3.2
id: authenticate-1.3.3.2-GjJK9eYqUJiCRua3CfCmGQ
key: authenticate-1.3.3.2-GjJK9eYqUJiCRua3CfCmGQ
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.
category: Web
author: Michael Snoyman, Hiromi Ishii, Arash Rouhani
exposed: True
exposed-modules:
    Web.Authenticate.Rpxnow Web.Authenticate.OpenId
    Web.Authenticate.BrowserId Web.Authenticate.OpenId.Providers
hidden-modules: Web.Authenticate.Internal OpenId2.Discovery
                OpenId2.Normalization OpenId2.Types OpenId2.XRDS
abi: 4d2a84782d86bfc512d82e6a64b822db
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/authenticate-1.3.3.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/authenticate-1.3.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/authenticate-1.3.3.2
hs-libraries: HSauthenticate-1.3.3.2-GjJK9eYqUJiCRua3CfCmGQ
depends:
    aeson-1.1.2.0-H9d5B7Pgw9tIbOpl8Ot3sY
    attoparsec-0.13.1.0-ETec0FJZJHgARrgZXhaej9 base-4.9.1.0
    blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO bytestring-0.10.8.1
    case-insensitive-1.2.0.10-3Sa52nt2lVR6gZGQE5fZZw
    conduit-1.2.11-LF3u2IjoGXz5B8eRQRwaoW containers-0.5.7.1
    http-conduit-2.2.3.1-CG9qtANv1KpDU9umUwoizB
    http-types-0.9.1-IqlxYYwrFhNBj6J7ATsByJ
    monad-control-1.0.2.0-10S0ywqdsCPHnUTlxJLEct
    network-uri-2.6.1.0-GzRvaV3udR3JtWfa3CLYOw
    resourcet-1.1.9-8dcH1R5asu46j8AjnoNKK5
    tagstream-conduit-0.5.5.3-opiAHRQEQ9Dt4aAYl6FfG
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    xml-conduit-1.5.1-8WyflpR3V7N9KUfVCoBUmr
haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
haddock-html: /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
